@@ -5,10 +5,8 @@ from pathlib import Path
 class MsgfmtPyBuildHook(BuildHookBase):
     PLUGIN_NAME = 'msgfmtpy'
 
-    @staticmethod
-    def convert(input: Path) -> bytes:
-        print(f'converting {input}')
-        with input.open('r') as file:
-            print(f'{file.read()=}')
+    def convert(self, input: Path) -> bytes:
         with input.open('rb') as file:
-            return make(file)
+            output = make(file)
+            print(output)
+            return output
